Module country_patterns

Module country_patterns 

Structs

MRZCountryPattern
Pattern information for a specific country to help extract document numbers from MRZ first-line content.

Functions

get_country_pattern
Return a reference to the first matching country pattern for first_line, based on whether first_line starts with the pattern’s id_prefix.
patterns
Return all available patterns as a slice.