Structs
- MRZCountry
Pattern - Pattern information for a specific country to help extract document numbers from MRZ first-line content.
Functions
- get_
country_ pattern - Return a reference to the first matching country pattern for
first_line, based on whetherfirst_linestarts with the pattern’sid_prefix. - patterns
- Return all available patterns as a slice.